commit libpfm for openSUSE:Factory

2020-03-05 Thread root
Hello community,

here is the log from the commit of package libpfm for openSUSE:Factory checked 
in at 2020-03-05 23:17:59

Comparing /work/SRC/openSUSE:Factory/libpfm (Old)
 and  /work/SRC/openSUSE:Factory/.libpfm.new.26092 (New)


Package is "libpfm"

Thu Mar  5 23:17:59 2020 rev:24 rq:781616 version:4.10.1

Changes:

--- /work/SRC/openSUSE:Factory/libpfm/libpfm.changes2019-10-22 
15:42:10.213492731 +0200
+++ /work/SRC/openSUSE:Factory/.libpfm.new.26092/libpfm.changes 2020-03-05 
23:18:04.597170281 +0100
@@ -1,0 +2,10 @@
+Tue Mar  3 02:49:22 UTC 2020 - Tony Jones 
+
+- Add Cavium ThunderX2 uncore support (jsc#SLE-8440)
+
+  New patch: thunderx2-uncore-support.patch
+  New patch: moved-tx2-uncore-event-to-separate-file.patch
+  New patch: add-thunderx2-dmc-events-and-ccpi-events.patch
+  New patch: removed-extra-fields-from-tx2_unc_data_t.patch
+
+---
@@ -4 +14 @@
-- Update Cavium ThunderX2 with now public events (jsc#SLE-1)
+- Update Cavium ThunderX2 with now public events (jsc#SLE-8440)

New:

  add-thunderx2-dmc-events-and-ccpi-events.patch
  moved-tx2-uncore-event-to-separate-file.patch
  removed-extra-fields-from-tx2_unc_data_t.patch
  thunderx2-uncore-support.patch



Other differences:
--
++ libpfm.spec ++
--- /var/tmp/diff_new_pack.RnYLGd/_old  2020-03-05 23:18:05.749170933 +0100
+++ /var/tmp/diff_new_pack.RnYLGd/_new  2020-03-05 23:18:05.749170933 +0100
@@ -1,7 +1,7 @@
 #
 # spec file for package libpfm
 #
-# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
+# Copyright (c) 2020 SUSE LLC
 #
 # All modifications and additions to the file contributed by third parties
 # remain the property of their copyright owners, unless otherwise agreed
@@ -33,6 +33,11 @@
 Patch1: 0001-s390-cpumf-add-support-for-counter-second-version-nu.patch
 Patch2: 0001-s390-cpumf-add-support-for-machine-type-8561.patch
 Patch3: update-cavium-thunderx2-with-now-public-events.patch
+Patch4: thunderx2-uncore-support.patch
+Patch5: moved-tx2-uncore-event-to-separate-file.patch
+Patch6: add-thunderx2-dmc-events-and-ccpi-events.patch
+Patch7: removed-extra-fields-from-tx2_unc_data_t.patch
+
 BuildRequires:  %{python_module devel}
 BuildRequires:  %{python_module setuptools}
 BuildRequires:  python-rpm-macros

++ add-thunderx2-dmc-events-and-ccpi-events.patch ++
From: Shay Gal-On 
Date: Mon Nov 25 12:00:15 2019 -0800
Subject: Add ThunderX2 DMC events and CCPI events
Git-commit: dc1da4573eb8d24bdf64b9bb5e04ed956075d712
References: jsc#SLE-1
Signed-off-by: Tony Jones 
X-Info: adjust for context, no 98218490 (CascadeLake X core PMU)

Add ThunderX2 DMC events and CCPI events

This patch adds missing 2 DMC events for ThunderX2
and adds support for the Cross Core Complex Interconnect
(CCPI) PMU and events.

The following PMU models are added:
 - tx2_ccpi0, tx2_ccpi1
 - tx2_dmc0, tx2_dmc1

Signed-off-by: Shay Gal-On 

diff --git a/lib/Makefile b/lib/Makefile
index 686264b..4a4dc3b 100644
--- a/lib/Makefile
+++ b/lib/Makefile
@@ -177,7 +177,7 @@ SRCS += pfmlib_arm_perf_event.c
 endif
 
 INCARCH = $(INC_ARM)
-SRCS   += pfmlib_arm.c pfmlib_arm_armv7_pmuv1.c pfmlib_arm_armv6.c 
pfml

commit libpfm for openSUSE:Factory

2019-10-22 Thread root
Hello community,

here is the log from the commit of package libpfm for openSUSE:Factory checked 
in at 2019-10-22 15:42:03

Comparing /work/SRC/openSUSE:Factory/libpfm (Old)
 and  /work/SRC/openSUSE:Factory/.libpfm.new.2352 (New)


Package is "libpfm"

Tue Oct 22 15:42:03 2019 rev:23 rq:741251 version:4.10.1

Changes:

--- /work/SRC/openSUSE:Factory/libpfm/libpfm.changes2019-08-19 
23:02:34.963442447 +0200
+++ /work/SRC/openSUSE:Factory/.libpfm.new.2352/libpfm.changes  2019-10-22 
15:42:10.213492731 +0200
@@ -1,0 +2,6 @@
+Fri Oct 18 18:11:38 UTC 2019 - Tony Jones 
+
+- Update Cavium ThunderX2 with now public events (jsc#SLE-1)
+  New patch: update-cavium-thunderx2-with-now-public-events.patch
+
+---

New:

  update-cavium-thunderx2-with-now-public-events.patch



Other differences:
--
++ libpfm.spec ++
--- /var/tmp/diff_new_pack.Ymk8eW/_old  2019-10-22 15:42:10.793493392 +0200
+++ /var/tmp/diff_new_pack.Ymk8eW/_new  2019-10-22 15:42:10.797493396 +0200
@@ -32,6 +32,7 @@
 Patch0: 0001-s390-cpumf-add-IBM-z14-ZR1-support.patch
 Patch1: 0001-s390-cpumf-add-support-for-counter-second-version-nu.patch
 Patch2: 0001-s390-cpumf-add-support-for-machine-type-8561.patch
+Patch3: update-cavium-thunderx2-with-now-public-events.patch
 BuildRequires:  %{python_module devel}
 BuildRequires:  %{python_module setuptools}
 BuildRequires:  python-rpm-macros

++ update-cavium-thunderx2-with-now-public-events.patch ++
From: Steve Walk 
Date: Tue Mar 20 09:37:56 2018 -0700
Subject: update Cavium ThunderX2 with now public events
Git-commit: 6c9e44b95a55b8bf62cbd64009c4c9b30964a66c
References: jsc#SLE-1
Signed-off-by: Tony Jones 

update Cavium ThunderX2 with now public events

This patch adds new model specific events to the
Cavium Thunder X2 core PMU. The updated list is based
on publicly available documentation from Cavium which
is available at:
https://cavium.com/resources.html

Signed-off-by: Steve Walk  

diff --git a/lib/events/arm_cavium_tx2_events.h 
b/lib/events/arm_cavium_tx2_events.h
index 67de9f8..198d33d 100644
--- a/lib/events/arm_cavium_tx2_events.h
+++ b/lib/events/arm_cavium_tx2_events.h
@@ -23,6 +23,9 @@
  *
  * ARM Architecture Reference Manual, ARMv8, for ARMv8-A architecture profile,
  * ARM DDI 0487B.a (ID033117)
+ *
+ * Cavium ThunderX2 C99XX PMU Events (Abridged), July 31, 2018
+ * https://cavium.com/resources.html
  */
 
 static const arm_entry_t arm_thunderx2_pe[]={
@@ -161,6 +164,11 @@ static const arm_entry_t arm_thunderx2_pe[]={
 .code = 0x1C,
 .desc = "Instruction architecturally executed (condition check pass)  
Write to translation table base"
},
+   {.name = "CHAIN",
+.modmsk = ARMV8_ATTRS,
+.code = 0x1E,
+.desc = "For odd-numbered counters, increments the count by one for 
each overflow of the proceeding even counter"
+   },
{.name = "L1D_CACHE_ALLOCATE",
 .modmsk = ARMV8_ATTRS,
 .code = 0x1F,
@@ -556,6 +564,274 @@ static const arm_entry_t arm_thunderx2_pe[]={
 .code = 0x91,
 .desc = "Release consistency instruction speculatively executed 
(store-release)"
},
-
-   /* END Cavium ThunderX2 specific events */
+   {.name = "L1D_LHS_VANOTP",
+.modmsk = ARMV8_ATTRS,
+.code = 0xC1,
+.desc = "A Load hit store retry"
+   },
+   {.name = "L1D_LHS_OVRLAP",
+.modmsk = ARMV8_ATTRS,
+.code = 0xC2,
+.desc = "A Load hit store retry, VA match, PA mismatch"
+   },
+   {.name = "L1D_LHS_VANOSD",
+.modmsk = ARMV8_ATTRS,
+.code = 0xC3,
+.desc = "A Load hit store retry, VA match, store data not issued"
+   },
+   {.name = "L1D_LHS_FWD",
+.modmsk = ARMV8_ATTRS,
+.code = 0xC4,
+.desc = "A Load hit store forwarding. Load completes"
+   },
+   {.name = "L1D_BNKCFL",
+.modmsk = ARMV8_ATTRS,
+.code = 0xC6,
+.desc = "Bank conflict load retry"
+   },
+   {.name = "L1D_LSMQ_FULL",
+.modmsk = ARMV8_ATTRS,
+.code = 0xC7,
+.desc = "LSMQ retry"
+   },
+   {.name = "L1D_LSMQ_HIT",
+.modmsk = ARMV8_ATTRS,
+.code = 0xC8,
+.desc = "LSMQ hit retry"
+   },
+   {.name = "L1D_EXPB_MISS",
+.modmsk = ARMV8_ATTRS,
+.code = 0xC9,
+.desc = "An external probe missed the L1"
+   },
+   {.name = "L1D_L2EV_MISS",
+.modmsk = ARMV8_ATTRS,
+.code = 0xCA,
+.desc = "An L2 evict operation missed the L1"
+   },
+   {.name = "L1D_EXPB_HITM",
+.modmsk

commit libpfm for openSUSE:Factory

2019-08-19 Thread root
Hello community,

here is the log from the commit of package libpfm for openSUSE:Factory checked 
in at 2019-08-19 23:02:34

Comparing /work/SRC/openSUSE:Factory/libpfm (Old)
 and  /work/SRC/openSUSE:Factory/.libpfm.new.22127 (New)


Package is "libpfm"

Mon Aug 19 23:02:34 2019 rev:22 rq:724596 version:4.10.1

Changes:

--- /work/SRC/openSUSE:Factory/libpfm/libpfm.changes2019-08-16 
15:32:55.749921203 +0200
+++ /work/SRC/openSUSE:Factory/.libpfm.new.22127/libpfm.changes 2019-08-19 
23:02:34.963442447 +0200
@@ -9 +9,3 @@
-- Add more patches for s390 fate#327911 bsc#1145464:
+- Add more patches for s390 fate#327911 bsc#1145464
+  These add support for ZR1 and add support for counter second version
+  number 6:



Other differences:
--



commit libpfm for openSUSE:Factory

2019-08-16 Thread root
Hello community,

here is the log from the commit of package libpfm for openSUSE:Factory checked 
in at 2019-08-16 15:32:53

Comparing /work/SRC/openSUSE:Factory/libpfm (Old)
 and  /work/SRC/openSUSE:Factory/.libpfm.new.22127 (New)


Package is "libpfm"

Fri Aug 16 15:32:53 2019 rev:21 rq:723469 version:4.10.1

Changes:

--- /work/SRC/openSUSE:Factory/libpfm/libpfm.changes2019-07-08 
15:10:02.427288406 +0200
+++ /work/SRC/openSUSE:Factory/.libpfm.new.22127/libpfm.changes 2019-08-16 
15:32:55.749921203 +0200
@@ -1,0 +2,13 @@
+Thu Aug 15 08:25:29 UTC 2019 - Tomáš Chvátal 
+
+- Add provides/obsoletes wrt bsc#1145710 to avoid file conflict
+
+---
+Wed Aug 14 09:44:49 UTC 2019 - Tomáš Chvátal 
+
+- Add more patches for s390 fate#327911 bsc#1145464:
+  * 0001-s390-cpumf-add-IBM-z14-ZR1-support.patch
+  * 0001-s390-cpumf-add-support-for-counter-second-version-nu.patch
+  * 0001-s390-cpumf-add-support-for-machine-type-8561.patch
+
+---

New:

  0001-s390-cpumf-add-IBM-z14-ZR1-support.patch
  0001-s390-cpumf-add-support-for-counter-second-version-nu.patch
  0001-s390-cpumf-add-support-for-machine-type-8561.patch



Other differences:
--
++ libpfm.spec ++
--- /var/tmp/diff_new_pack.Yw1F7p/_old  2019-08-16 15:32:56.145921088 +0200
+++ /var/tmp/diff_new_pack.Yw1F7p/_new  2019-08-16 15:32:56.149921087 +0200
@@ -17,18 +17,21 @@
 
 
 %global python_config CONFIG_PFMLIB_NOPYTHON=y
-%bcond_without python2
 %{?!python_module:%define python_module() python-%{**} python3-%{**}}
 %define vname   libpfm4
+%bcond_without python2
 Name:   libpfm
 Version:4.10.1
 Release:0
 Summary:Library to encode performance events
 License:MIT
 Group:  Development/Libraries/C and C++
-Url:http://perfmon2.sourceforge.net/
+URL:http://perfmon2.sourceforge.net/
 Source: 
http://downloads.sourceforge.net/project/perfmon2/libpfm4/%{name}-%{version}.tar.gz
 Source1:baselibs.conf
+Patch0: 0001-s390-cpumf-add-IBM-z14-ZR1-support.patch
+Patch1: 0001-s390-cpumf-add-support-for-counter-second-version-nu.patch
+Patch2: 0001-s390-cpumf-add-support-for-machine-type-8561.patch
 BuildRequires:  %{python_module devel}
 BuildRequires:  %{python_module setuptools}
 BuildRequires:  python-rpm-macros
@@ -72,6 +75,8 @@
 %package -n python2-%{name}
 Summary:Python bindings for libpfm and perf_event_open system call
 Group:  Development/Libraries/Python
+Provides:   python-%{name}
+Obsoletes:  python-%{name}
 Requires:   %{vname} = %{version}
 
 %description -n python2-%{name}
@@ -85,13 +90,13 @@
 %description -n python3-%{name}
 This package provides python3 bindings for the libpfm4 package and the 
perf_event_open system call.
 
-
 %prep
 %setup -q
 # disable werror
 sed -i \
 -e 's:-Werror::g' \
 config.mk
+%autopatch -p1
 
 %build
 %global _lto_cflags %{_lto_cflags} -ffat-lto-objects

++ 0001-s390-cpumf-add-IBM-z14-ZR1-support.patch ++
>From dc643f4a460063a628b4bfba57dbbb36673a0789 Mon Sep 17 00:00:00 2001
From: Thomas Richter 
Date: Thu, 11 Jul 2019 17:48:03 -0700
Subject: [PATCH] s390/cpumf: add IBM z14 ZR1 support

Add support for machine type 0x3907.

Signed-off-by: Thomas Richter 
---
 lib/pfmlib_s390x_cpumf.c | 1 +
 1 file changed, 1 insertion(+)

diff --git a/lib/pfmlib_s390x_cpumf.c b/lib/pfmlib_s390x_cpumf.c
index 4e03fc4..7566aa0 100644
--- a/lib/pfmlib_s390x_cpumf.c
+++ b/lib/pfmlib_s390x_cpumf.c
@@ -192,6 +192,7 @@ static int pfm_cpumcf_init(void *this)
ext_set_count = LIBPFM_ARRAY_SIZE(cpumcf_z13_counters);
break;
case 3906:  /* IBM z14  */
+   case 3907:  /* IBM z14 ZR1  */
ext_set = cpumcf_z14_counters;
ext_set_count = LIBPFM_ARRAY_SIZE(cpumcf_z14_counters);
break;
-- 
2.22.0

++ 0001-s390-cpumf-add-support-for-counter-second-version-nu.patch ++
>From c08003fb085e23f2229e58cc176fcfcf58a3b238 Mon Sep 17 00:00:00 2001
From: Thomas Richter 
Date: Thu, 11 Jul 2019 17:49:42 -0700
Subject: [PATCH] s390/cpumf: add support for counter second version number 6

IBM added secound version number 6 in the CPU Measurement
Counter facility to indicate additional counters in the
crypto counter set.

Signed-off-by: Thomas Richter 
---
 lib/events/s390x_cpumf_events.h | 39 +
 lib/pfmlib_s390x_cpumf.c|  2 ++
 2 files changed, 41 insertions(+)

diff --git a/lib/events/s390x_cpumf_events.h b/lib/events/s390x_cpumf_events.h
index 8be1d55..8587a3b 100644
--- a/lib/events/s390x_cpumf_events.h
+++ 

commit libpfm for openSUSE:Factory

2019-07-08 Thread root
Hello community,

here is the log from the commit of package libpfm for openSUSE:Factory checked 
in at 2019-07-08 15:10:01

Comparing /work/SRC/openSUSE:Factory/libpfm (Old)
 and  /work/SRC/openSUSE:Factory/.libpfm.new.4615 (New)


Package is "libpfm"

Mon Jul  8 15:10:01 2019 rev:20 rq:713342 version:4.10.1

Changes:

--- /work/SRC/openSUSE:Factory/libpfm/libpfm.changes2018-11-06 
13:59:37.707824106 +0100
+++ /work/SRC/openSUSE:Factory/.libpfm.new.4615/libpfm.changes  2019-07-08 
15:10:02.427288406 +0200
@@ -1,0 +2,5 @@
+Thu Jul  4 06:35:27 UTC 2019 - Martin Liška 
+
+- Use FAT LTO objects in order to provide proper static library.
+
+---



Other differences:
--
++ libpfm.spec ++
--- /var/tmp/diff_new_pack.p4vamn/_old  2019-07-08 15:10:03.623289553 +0200
+++ /var/tmp/diff_new_pack.p4vamn/_new  2019-07-08 15:10:03.631289561 +0200
@@ -1,7 +1,7 @@
 #
 # spec file for package libpfm
 #
-# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
+# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
 #
 # All modifications and additions to the file contributed by third parties
 # remain the property of their copyright owners, unless otherwise agreed
@@ -94,6 +94,7 @@
 config.mk
 
 %build
+%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
 export CFLAGS="%{optflags}"
 make %{?_smp_mflags} %{python_config}
 




commit libpfm for openSUSE:Factory

2018-11-06 Thread root
Hello community,

here is the log from the commit of package libpfm for openSUSE:Factory checked 
in at 2018-11-06 13:59:34

Comparing /work/SRC/openSUSE:Factory/libpfm (Old)
 and  /work/SRC/openSUSE:Factory/.libpfm.new (New)


Package is "libpfm"

Tue Nov  6 13:59:34 2018 rev:19 rq:643937 version:4.10.1

Changes:

--- /work/SRC/openSUSE:Factory/libpfm/libpfm.changes2018-08-10 
09:44:52.325796748 +0200
+++ /work/SRC/openSUSE:Factory/.libpfm.new/libpfm.changes   2018-11-06 
13:59:37.707824106 +0100
@@ -4 +4 @@
-- Version update to 4.10.1 fate#326340:
+- Version update to 4.10.1 fate#326340 fate#326387:



Other differences:
--
++ libpfm.spec ++
--- /var/tmp/diff_new_pack.BDQATa/_old  2018-11-06 13:59:38.679822848 +0100
+++ /var/tmp/diff_new_pack.BDQATa/_new  2018-11-06 13:59:38.683822844 +0100
@@ -12,7 +12,7 @@
 # license that conforms to the Open Source Definition (Version 1.9)
 # published by the Open Source Initiative.
 
-# Please submit bugfixes or comments via http://bugs.opensuse.org/
+# Please submit bugfixes or comments via https://bugs.opensuse.org/
 #
 
 




commit libpfm for openSUSE:Factory

2018-08-10 Thread root
Hello community,

here is the log from the commit of package libpfm for openSUSE:Factory checked 
in at 2018-08-10 09:44:46

Comparing /work/SRC/openSUSE:Factory/libpfm (Old)
 and  /work/SRC/openSUSE:Factory/.libpfm.new (New)


Package is "libpfm"

Fri Aug 10 09:44:46 2018 rev:18 rq:628121 version:4.10.1

Changes:

--- /work/SRC/openSUSE:Factory/libpfm/libpfm.changes2018-06-22 
13:35:40.458004941 +0200
+++ /work/SRC/openSUSE:Factory/.libpfm.new/libpfm.changes   2018-08-10 
09:44:52.325796748 +0200
@@ -1,0 +2,14 @@
+Wed Aug  8 14:18:34 UTC 2018 - tchva...@suse.com
+
+- Version update to 4.10.1 fate#326340:
+  * Fix build issues on Cavium Tunder X2 from v4.10
+  * Update to Intel Skylake event table
+  * Intel Skylake X uncore PMUs support (all PMU boxes)
+  * Intel Knight Mill (KNM) core PMU support
+  * Cavium Thunder X2 core PMU support
+  * various event table updates
+  * various bug fixes
+- Drop patch merged upstream:
+  * libpfm-python3.patch
+
+---

Old:

  libpfm-4.9.0.tar.gz
  libpfm-python3.patch

New:

  libpfm-4.10.1.tar.gz



Other differences:
--
++ libpfm.spec ++
--- /var/tmp/diff_new_pack.doSvrr/_old  2018-08-10 09:44:52.753797434 +0200
+++ /var/tmp/diff_new_pack.doSvrr/_new  2018-08-10 09:44:52.757797440 +0200
@@ -21,7 +21,7 @@
 %{?!python_module:%define python_module() python-%{**} python3-%{**}}
 %define vname   libpfm4
 Name:   libpfm
-Version:4.9.0
+Version:4.10.1
 Release:0
 Summary:Library to encode performance events
 License:MIT
@@ -29,7 +29,6 @@
 Url:http://perfmon2.sourceforge.net/
 Source: 
http://downloads.sourceforge.net/project/perfmon2/libpfm4/%{name}-%{version}.tar.gz
 Source1:baselibs.conf
-Patch0: libpfm-python3.patch
 BuildRequires:  %{python_module devel}
 BuildRequires:  %{python_module setuptools}
 BuildRequires:  python-rpm-macros
@@ -89,7 +88,6 @@
 
 %prep
 %setup -q
-%patch0 -p1
 # disable werror
 sed -i \
 -e 's:-Werror::g' \

++ libpfm-4.9.0.tar.gz -> libpfm-4.10.1.tar.gz ++
 20822 lines of diff (skipped)




commit libpfm for openSUSE:Factory

2018-06-22 Thread root
Hello community,

here is the log from the commit of package libpfm for openSUSE:Factory checked 
in at 2018-06-22 13:35:36

Comparing /work/SRC/openSUSE:Factory/libpfm (Old)
 and  /work/SRC/openSUSE:Factory/.libpfm.new (New)


Package is "libpfm"

Fri Jun 22 13:35:36 2018 rev:17 rq:618287 version:4.9.0

Changes:

--- /work/SRC/openSUSE:Factory/libpfm/libpfm.changes2018-01-24 
15:24:41.434677587 +0100
+++ /work/SRC/openSUSE:Factory/.libpfm.new/libpfm.changes   2018-06-22 
13:35:40.458004941 +0200
@@ -73 +73 @@
-  in devel package.
+  in devel package. Backport from Factory. (bnc#1017407)



Other differences:
--



commit libpfm for openSUSE:Factory

2018-01-24 Thread root
Hello community,

here is the log from the commit of package libpfm for openSUSE:Factory checked 
in at 2018-01-24 15:24:40

Comparing /work/SRC/openSUSE:Factory/libpfm (Old)
 and  /work/SRC/openSUSE:Factory/.libpfm.new (New)


Package is "libpfm"

Wed Jan 24 15:24:40 2018 rev:16 rq:568494 version:4.9.0

Changes:

--- /work/SRC/openSUSE:Factory/libpfm/libpfm.changes2018-01-20 
11:19:44.731916075 +0100
+++ /work/SRC/openSUSE:Factory/.libpfm.new/libpfm.changes   2018-01-24 
15:24:41.434677587 +0100
@@ -1,0 +2,6 @@
+Tue Jan 23 08:52:49 UTC 2018 - tchva...@suse.com
+
+- Remove useless byte-compiling for py2 that breaks py3 only build
+- Update libpfm-python3.patch to fix one stray identation issue
+
+---



Other differences:
--
++ libpfm.spec ++
--- /var/tmp/diff_new_pack.tvedMC/_old  2018-01-24 15:24:42.066648027 +0100
+++ /var/tmp/diff_new_pack.tvedMC/_new  2018-01-24 15:24:42.066648027 +0100
@@ -122,11 +122,6 @@
 %python_install
 popd
 
-# temp hack to fix rpmlint file-contains-buildroot for *.pyc
-# http://lists.opensuse.org/opensuse-factory/2012-01/msg00235.html
-find "%{buildroot}/%{python_sitearch}/" -name '*.pyc' -delete
-python -c 'import compileall; 
compileall.compile_dir("%{buildroot}%{python_sitearch}/", 
ddir="%{python_sitearch}/", force=1)'
-
 %post -n %{vname} -p /sbin/ldconfig
 %postun-n %{vname} -p /sbin/ldconfig
 

++ libpfm-python3.patch ++
--- /var/tmp/diff_new_pack.tvedMC/_old  2018-01-24 15:24:42.106646156 +0100
+++ /var/tmp/diff_new_pack.tvedMC/_new  2018-01-24 15:24:42.110645968 +0100
@@ -22,7 +22,7 @@
 +print(e.info.name, e.info.code)
  for a in e.attrs():
 -print '\t\t', a.name, a.code
-+print('\t\t', a.name, a.code)
++  print('\t\t', a.name, a.code)
 Index: libpfm-4.9.0/python/sys.py
 ===
 --- libpfm-4.9.0.orig/python/sys.py




commit libpfm for openSUSE:Factory

2018-01-20 Thread root
Hello community,

here is the log from the commit of package libpfm for openSUSE:Factory checked 
in at 2018-01-20 11:19:42

Comparing /work/SRC/openSUSE:Factory/libpfm (Old)
 and  /work/SRC/openSUSE:Factory/.libpfm.new (New)


Package is "libpfm"

Sat Jan 20 11:19:42 2018 rev:15 rq:567404 version:4.9.0

Changes:

--- /work/SRC/openSUSE:Factory/libpfm/libpfm.changes2017-08-24 
18:27:38.014721325 +0200
+++ /work/SRC/openSUSE:Factory/.libpfm.new/libpfm.changes   2018-01-20 
11:19:44.731916075 +0100
@@ -1,0 +2,24 @@
+Wed Jan 17 15:52:07 UTC 2018 - tchva...@suse.com
+
+- Add patch to build and work with python3:
+  * libpfm-python3.patch
+- Build the python parts using singlespec macros to allow switching
+  as needed
+
+---
+Wed Jan 17 15:30:33 UTC 2018 - tchva...@suse.com
+
+- Update to 4.9.0:
+  * Intel Broadwell EP uncore PMUs support (all PMU boxes)
+  * AMD Fam17h (Zen) core PMU support
+  * IBM Power9 core PMU support
+  * AMD Fam16h (Jaguar) support
+  * various event table updates
+  * various bug fixes
+- Drop upstream merged patches:
+  * libpfm_add-power9-entries-to-validate_power-c.patch
+  * libpfm_enable-ibm-power9-core-pmu-support-beta.patch
+  * libpfm_fix-power9-event-file-header.patch
+  * libpfm_power9-event-list-update-for-perfmon2.patch
+
+---

Old:

  libpfm-4.8.0.tar.gz
  libpfm_add-power9-entries-to-validate_power-c.patch
  libpfm_enable-ibm-power9-core-pmu-support-beta.patch
  libpfm_fix-power9-event-file-header.patch
  libpfm_power9-event-list-update-for-perfmon2.patch

New:

  libpfm-4.9.0.tar.gz
  libpfm-python3.patch



Other differences:
--
++ libpfm.spec ++
--- /var/tmp/diff_new_pack.APqQvg/_old  2018-01-20 11:19:45.795866335 +0100
+++ /var/tmp/diff_new_pack.APqQvg/_new  2018-01-20 11:19:45.795866335 +0100
@@ -1,7 +1,7 @@
 #
 # spec file for package libpfm
 #
-# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
+# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
 #
 # All modifications and additions to the file contributed by third parties
 # remain the property of their copyright owners, unless otherwise agreed
@@ -16,9 +16,12 @@
 #
 
 
+%global python_config CONFIG_PFMLIB_NOPYTHON=y
+%bcond_without python2
+%{?!python_module:%define python_module() python-%{**} python3-%{**}}
 %define vname   libpfm4
 Name:   libpfm
-Version:4.8.0
+Version:4.9.0
 Release:0
 Summary:Library to encode performance events
 License:MIT
@@ -26,14 +29,11 @@
 Url:http://perfmon2.sourceforge.net/
 Source: 
http://downloads.sourceforge.net/project/perfmon2/libpfm4/%{name}-%{version}.tar.gz
 Source1:baselibs.conf
-Patch1: libpfm_enable-ibm-power9-core-pmu-support-beta.patch
-Patch2: libpfm_fix-power9-event-file-header.patch
-Patch3: libpfm_power9-event-list-update-for-perfmon2.patch
-Patch4: libpfm_add-power9-entries-to-validate_power-c.patch
-
-BuildRequires:  python-devel
+Patch0: libpfm-python3.patch
+BuildRequires:  %{python_module devel}
+BuildRequires:  %{python_module setuptools}
+BuildRequires:  python-rpm-macros
 BuildRequires:  swig >= 2.0.5
-BuildRoot:  %{_tmppath}/%{name}-%{version}-build
 
 %description
 This package provides a library that can be used to encode events into the
@@ -70,20 +70,26 @@
 %description devel-static
 This package contains the static variant of libpfm.
 
-%package -n python-%{name}
+%package -n python2-%{name}
 Summary:Python bindings for libpfm and perf_event_open system call
 Group:  Development/Libraries/Python
 Requires:   %{vname} = %{version}
 
-%description -n python-%{name}
+%description -n python2-%{name}
 This package provides python bindings for the libpfm4 package and the 
perf_event_open system call.
 
+%package -n python3-%{name}
+Summary:Python3 bindings for libpfm and perf_event_open system call
+Group:  Development/Libraries/Python
+Requires:   %{vname} = %{version}
+
+%description -n python3-%{name}
+This package provides python3 bindings for the libpfm4 package and the 
perf_event_open system call.
+
+
 %prep
 %setup -q
-%patch1 -p1
-%patch2 -p1
-%patch3 -p1
-%patch4 -p1
+%patch0 -p1
 # disable werror
 sed -i \
 -e 's:-Werror::g' \
@@ -91,11 +97,14 @@
 
 %build
 export CFLAGS="%{optflags}"
-%global python_config CONFIG_PFMLIB_NOPYTHON=n
 make %{?_smp_mflags} %{python_config}
 
+pushd python
+%python_build
+popd
+
 %install
-%global python_config CONFIG_PFMLIB_NOPYTHON=n 
PYTHON_PREFIX="%{buildroot}/%{py_prefix}"
+%global python_config %{python_config}
 make \
 PREFIX="%{b

commit libpfm for openSUSE:Factory

2017-08-24 Thread root
Hello community,

here is the log from the commit of package libpfm for openSUSE:Factory checked 
in at 2017-08-24 18:27:25

Comparing /work/SRC/openSUSE:Factory/libpfm (Old)
 and  /work/SRC/openSUSE:Factory/.libpfm.new (New)


Package is "libpfm"

Thu Aug 24 18:27:25 2017 rev:14 rq:517255 version:4.8.0

Changes:

--- /work/SRC/openSUSE:Factory/libpfm/libpfm.changes2017-01-23 
11:35:44.387918362 +0100
+++ /work/SRC/openSUSE:Factory/.libpfm.new/libpfm.changes   2017-08-24 
18:27:38.014721325 +0200
@@ -1,0 +2,9 @@
+Wed Aug 16 17:06:19 UTC 2017 - to...@suse.com
+
+- Add Power9 support (FATE#322257) 
+  New patch: libpfm_enable-ibm-power9-core-pmu-support-beta.patch
+  New patch: libpfm_fix-power9-event-file-header.patch
+  New patch: libpfm_power9-event-list-update-for-perfmon2.patch
+  New patch: libpfm_add-power9-entries-to-validate_power-c.patch
+
+---

New:

  libpfm_add-power9-entries-to-validate_power-c.patch
  libpfm_enable-ibm-power9-core-pmu-support-beta.patch
  libpfm_fix-power9-event-file-header.patch
  libpfm_power9-event-list-update-for-perfmon2.patch



Other differences:
--
++ libpfm.spec ++
--- /var/tmp/diff_new_pack.nIYox0/_old  2017-08-24 18:27:47.453391534 +0200
+++ /var/tmp/diff_new_pack.nIYox0/_new  2017-08-24 18:27:47.453391534 +0200
@@ -26,6 +26,11 @@
 Url:http://perfmon2.sourceforge.net/
 Source: 
http://downloads.sourceforge.net/project/perfmon2/libpfm4/%{name}-%{version}.tar.gz
 Source1:baselibs.conf
+Patch1: libpfm_enable-ibm-power9-core-pmu-support-beta.patch
+Patch2: libpfm_fix-power9-event-file-header.patch
+Patch3: libpfm_power9-event-list-update-for-perfmon2.patch
+Patch4: libpfm_add-power9-entries-to-validate_power-c.patch
+
 BuildRequires:  python-devel
 BuildRequires:  swig >= 2.0.5
 BuildRoot:  %{_tmppath}/%{name}-%{version}-build
@@ -75,6 +80,10 @@
 
 %prep
 %setup -q
+%patch1 -p1
+%patch2 -p1
+%patch3 -p1
+%patch4 -p1
 # disable werror
 sed -i \
 -e 's:-Werror::g' \

++ libpfm_add-power9-entries-to-validate_power-c.patch ++
From: Will Schmidt 
Date: Tue, 6 Jun 2017 11:09:17 -0500
Subject: add power9 entries to validate_power.c
Git-repo: git://git.code.sf.net/p/perfmon2/libpfm4
Git-commit: ce5b320031f75f9a9881333c13902d5541f91cc8
References: FATE#322254
Signed-off-by: Tony Jones 

Hi,

Update the validate_power test to include power9 entries.

sniff-test run output:
$ ./validate
Libpfm structure tests:
libpfm ABI version : 0
pfm_pmu_info_t : Passed
pfm_event_info_t : Passed
pfm_event_attr_info_t : Passed
pfm_pmu_encode_arg_t : Passed
pfm_perf_encode_arg_t : Passed
Libpfm internal table tests:

checking power9 (946 events): Passed
Architecture specific tests:
 20 PowerPC events: 0 errors
All tests passed

Signed-off-by:  Will Schmidt 
---
 tests/validate_power.c | 14 ++
 1 file changed, 14 insertions(+)

diff --git a/tests/validate_power.c b/tests/validate_power.c
index 74ab30c..617efca 100644
--- a/tests/validate_power.c
+++ b/tests/validate_power.c
@@ -157,6 +157,20 @@ static const test_event_t ppc_test_events[]={
  .codes[0] = 0xde200201e6ull,
  .fstr = "power8::PM_RC_LIFETIME_EXC_32",
},
+   { SRC_LINE,
+ .name = "power9::PM_CYC",
+ .ret  = PFM_SUCCESS,
+ .count = 1,
+ .codes[0] = 0x1001e,
+ .fstr = "power9::PM_CYC",
+   },
+   { SRC_LINE,
+ .name = "power9::PM_INST_DISP",
+ .ret  = PFM_SUCCESS,
+ .count = 1,
+ .codes[0] = 0x200f2,
+ .fstr = "power9::PM_INST_DISP",
+   },
 { SRC_LINE,
   .name = "powerpc_nest_mcs_read::MCS_00",
   .ret = PFM_SUCCESS,

++ libpfm_enable-ibm-power9-core-pmu-support-beta.patch ++
 6644 lines (skipped)

++ libpfm_fix-power9-event-file-header.patch ++
From: Stephane Eranian 
Date: Fri, 2 Jun 2017 12:10:17 -0700
Subject: fix Power9 event file header
Git-repo: git://git.code.sf.net/p/perfmon2/libpfm4
Git-commit: 930ef5dbcc5d0d663979e16079aac12a7872d44d
References: FATE#322254
Signed-off-by: Tony Jones 

Had __POWER8_EVENTS_H__ instead of __POWER9_EVENTS_H__

Signed-off-by: Stephane Eranian 
---
 lib/events/power9_events.h | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/lib/events/power9_events.h b/lib/events/power9_events.h
index 7414687..765e9bd 100644
--- a/lib/events/power9_events.h
+++ b/lib/events/power9_events.h
@@ -20,7 +20,7 @@
 */
 
 #ifndef __POWER9_EVENTS_H__
-#define __POWER8_EVENTS_H__
+#define __POWER9_EVENTS_H__
 
 #define POWER9_PME_PM_IERAT_RELOAD 0
 #define POWER9_PME_PM_TM_OUTER

commit libpfm for openSUSE:Factory

2017-01-23 Thread root
Hello community,

here is the log from the commit of package libpfm for openSUSE:Factory checked 
in at 2017-01-23 11:35:43

Comparing /work/SRC/openSUSE:Factory/libpfm (Old)
 and  /work/SRC/openSUSE:Factory/.libpfm.new (New)


Package is "libpfm"

Changes:

--- /work/SRC/openSUSE:Factory/libpfm/libpfm.changes2016-12-29 
22:52:00.855371500 +0100
+++ /work/SRC/openSUSE:Factory/.libpfm.new/libpfm.changes   2017-01-23 
11:35:44.387918362 +0100
@@ -1,0 +2,5 @@
+Sat Jan 14 14:53:05 UTC 2017 - mplus...@suse.com
+
+- Cleanup spec file
+
+---



Other differences:
--
++ libpfm.spec ++
--- /var/tmp/diff_new_pack.Q6gjPC/_old  2017-01-23 11:35:44.851852571 +0100
+++ /var/tmp/diff_new_pack.Q6gjPC/_new  2017-01-23 11:35:44.855852003 +0100
@@ -1,7 +1,7 @@
 #
 # spec file for package libpfm
 #
-# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
+# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
 #
 # All modifications and additions to the file contributed by third parties
 # remain the property of their copyright owners, unless otherwise agreed
@@ -93,10 +93,12 @@
 %{python_config} \
 LDCONFIG=/bin/true \
 install
-mkdir -p %{buildroot}/%{_bindir}
-install -m 0755 examples/check_events %{buildroot}/%{_bindir}/check_events
-install -m 0755 examples/showevtinfo %{buildroot}/%{_bindir}/showevtinfo
-install -m 0755 perf_examples/evt2raw %{buildroot}/%{_bindir}/evt2raw
+install -D -p -m 0755 examples/check_events \
+  %{buildroot}/%{_bindir}/check_events
+install -D -p -m 0755 examples/showevtinfo \
+  %{buildroot}/%{_bindir}/showevtinfo
+install -D -p -m 0755 perf_examples/evt2raw \
+  %{buildroot}/%{_bindir}/evt2raw
 
 # temp hack to fix rpmlint file-contains-buildroot for *.pyc
 # http://lists.opensuse.org/opensuse-factory/2012-01/msg00235.html
@@ -104,29 +106,28 @@
 python -c 'import compileall; 
compileall.compile_dir("%{buildroot}%{python_sitearch}/", 
ddir="%{python_sitearch}/", force=1)'
 
 %post -n %{vname} -p /sbin/ldconfig
-
 %postun-n %{vname} -p /sbin/ldconfig
 
 %files -n %{vname}
-%defattr(644,root,root,755)
+%defattr(-,root,root)
 %doc README
-%attr(755,root,root) %{_libdir}/lib*.so.*
+%{_libdir}/libpfm.so.*
 
 %files devel
-%defattr(644,root,root,755)
+%defattr(-,root,root)
 %{_includedir}/*
 %{_mandir}/man3/*
 %{_libdir}/lib*.so
-%attr(755,root,root) %{_bindir}/check_events
-%attr(755,root,root) %{_bindir}/showevtinfo
-%attr(755,root,root) %{_bindir}/evt2raw
+%{_bindir}/check_events
+%{_bindir}/showevtinfo
+%{_bindir}/evt2raw
 
 %files devel-static
 %defattr(-,root,root)
 %{_libdir}/lib*.a
 
 %files -n python-%{name}
-%defattr(644,root,root,755)
-%attr(755,root,root) %{python_sitearch}/*
+%defattr(-,root,root)
+%{python_sitearch}/*
 
 %changelog




commit libpfm for openSUSE:Factory

2016-06-19 Thread h_root
Hello community,

here is the log from the commit of package libpfm for openSUSE:Factory checked 
in at 2016-06-19 10:50:19

Comparing /work/SRC/openSUSE:Factory/libpfm (Old)
 and  /work/SRC/openSUSE:Factory/.libpfm.new (New)


Package is "libpfm"

Changes:

--- /work/SRC/openSUSE:Factory/libpfm/libpfm.changes2016-01-22 
01:10:13.0 +0100
+++ /work/SRC/openSUSE:Factory/.libpfm.new/libpfm.changes   2016-06-19 
10:50:22.0 +0200
@@ -1,0 +2,11 @@
+Fri Jun 17 08:00:28 UTC 2016 - tchva...@suse.com
+
+- Version bump to 4.7.0:
+  * Intel Skylake core PMU
+  * Intel Haswell-EP uncore PMUs
+  * Intel Broadwell-DE
+  * Major update on Intel event tables
+  * bug fixes and many other improvements
+- Respect cflags, disable werror bnc#985166
+
+---

Old:

  libpfm-4.6.0.tar.gz

New:

  libpfm-4.7.0.tar.gz



Other differences:
--
++ libpfm.spec ++
--- /var/tmp/diff_new_pack.gXxgZe/_old  2016-06-19 10:50:23.0 +0200
+++ /var/tmp/diff_new_pack.gXxgZe/_new  2016-06-19 10:50:23.0 +0200
@@ -18,7 +18,7 @@
 
 %define vname   libpfm4
 Name:   libpfm
-Version:4.6.0
+Version:4.7.0
 Release:0
 Summary:Library to encode performance events
 License:MIT
@@ -75,8 +75,13 @@
 
 %prep
 %setup -q
+# disable werror
+sed -i \
+-e 's:-Werror::g' \
+config.mk
 
 %build
+export CFLAGS="%{optflags}"
 %global python_config CONFIG_PFMLIB_NOPYTHON=n
 make %{?_smp_mflags} %{python_config}
 

++ libpfm-4.6.0.tar.gz -> libpfm-4.7.0.tar.gz ++
 21030 lines of diff (skipped)




commit libpfm for openSUSE:Factory

2016-01-21 Thread h_root
Hello community,

here is the log from the commit of package libpfm for openSUSE:Factory checked 
in at 2016-01-21 23:44:36

Comparing /work/SRC/openSUSE:Factory/libpfm (Old)
 and  /work/SRC/openSUSE:Factory/.libpfm.new (New)


Package is "libpfm"

Changes:

--- /work/SRC/openSUSE:Factory/libpfm/libpfm.changes2015-06-01 
09:55:53.0 +0200
+++ /work/SRC/openSUSE:Factory/.libpfm.new/libpfm.changes   2016-01-22 
01:10:13.0 +0100
@@ -1,0 +2,6 @@
+Tue Jan 19 18:17:58 UTC 2016 - to...@suse.com
+
+- Package useful utilities (check_events. evt2raw and showevtinfo)
+  in devel package.
+
+---



Other differences:
--
++ libpfm.spec ++
--- /var/tmp/diff_new_pack.u2togP/_old  2016-01-22 01:10:15.0 +0100
+++ /var/tmp/diff_new_pack.u2togP/_new  2016-01-22 01:10:15.0 +0100
@@ -1,7 +1,7 @@
 #
 # spec file for package libpfm
 #
-# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
+# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
 #
 # All modifications and additions to the file contributed by third parties
 # remain the property of their copyright owners, unless otherwise agreed
@@ -88,6 +88,10 @@
 %{python_config} \
 LDCONFIG=/bin/true \
 install
+mkdir -p %{buildroot}/%{_bindir}
+install -m 0755 examples/check_events %{buildroot}/%{_bindir}/check_events
+install -m 0755 examples/showevtinfo %{buildroot}/%{_bindir}/showevtinfo
+install -m 0755 perf_examples/evt2raw %{buildroot}/%{_bindir}/evt2raw
 
 # temp hack to fix rpmlint file-contains-buildroot for *.pyc
 # http://lists.opensuse.org/opensuse-factory/2012-01/msg00235.html
@@ -108,6 +112,9 @@
 %{_includedir}/*
 %{_mandir}/man3/*
 %{_libdir}/lib*.so
+%attr(755,root,root) %{_bindir}/check_events
+%attr(755,root,root) %{_bindir}/showevtinfo
+%attr(755,root,root) %{_bindir}/evt2raw
 
 %files devel-static
 %defattr(-,root,root)




commit libpfm for openSUSE:Factory

2015-06-01 Thread h_root
Hello community,

here is the log from the commit of package libpfm for openSUSE:Factory checked 
in at 2015-06-01 09:55:52

Comparing /work/SRC/openSUSE:Factory/libpfm (Old)
 and  /work/SRC/openSUSE:Factory/.libpfm.new (New)


Package is "libpfm"

Changes:

--- /work/SRC/openSUSE:Factory/libpfm/libpfm.changes2015-03-16 
09:42:27.0 +0100
+++ /work/SRC/openSUSE:Factory/.libpfm.new/libpfm.changes   2015-06-01 
09:55:53.0 +0200
@@ -4 +4 @@
-- Version bump to 4.6.0:
+- Version bump to 4.6.0 fate#318068:
@@ -13,0 +14,2 @@
+- Drop obsolete patch:
+  * libpfm-add-ibm-power8-support.patch
@@ -31,0 +34,5 @@
+
+---
+Thu Jan  9 18:28:09 UTC 2014 - to...@suse.com
+
+- Add Power8 support (libpfm-add-ibm-power8-support.patch) FATE#315274



Other differences:
--



commit libpfm for openSUSE:Factory

2015-03-16 Thread h_root
Hello community,

here is the log from the commit of package libpfm for openSUSE:Factory checked 
in at 2015-03-16 09:42:26

Comparing /work/SRC/openSUSE:Factory/libpfm (Old)
 and  /work/SRC/openSUSE:Factory/.libpfm.new (New)


Package is "libpfm"

Changes:

--- /work/SRC/openSUSE:Factory/libpfm/libpfm.changes2015-02-16 
21:14:50.0 +0100
+++ /work/SRC/openSUSE:Factory/.libpfm.new/libpfm.changes   2015-03-16 
09:42:27.0 +0100
@@ -1,0 +2,16 @@
+Fri Mar 13 14:13:09 UTC 2015 - tchva...@suse.com
+
+- Version bump to 4.6.0:
+  * Intel Broadwell (desktop core)
+  * Intel Haswell-EP (core)
+  * Applied Micro X-Gene processor
+  * ARM A53 processor
+  * Intel SNB, IVB, HSW event table updates
+  * IBM Power8 event table updates
+  * improved Intel x86 model detection
+  * bug fixes and many other improvements
+- Cleanup with spec-cleaner
+- Remove with_python switch that always evaluated as true
+  * If the need is really here it should be used as %bcond_without
+
+---

Old:

  libpfm-4.5.0.tar.gz

New:

  libpfm-4.6.0.tar.gz



Other differences:
--
++ libpfm.spec ++
--- /var/tmp/diff_new_pack.aTFu9y/_old  2015-03-16 09:42:28.0 +0100
+++ /var/tmp/diff_new_pack.aTFu9y/_new  2015-03-16 09:42:28.0 +0100
@@ -1,7 +1,7 @@
 #
 # spec file for package libpfm
 #
-# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
+# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
 #
 # All modifications and additions to the file contributed by third parties
 # remain the property of their copyright owners, unless otherwise agreed
@@ -16,22 +16,18 @@
 #
 
 
-%{!?with_python: %global with_python 1}
-
+%define vname   libpfm4
 Name:   libpfm
-Version:4.5.0
+Version:4.6.0
 Release:0
-%define vname   libpfm4
 Summary:Library to encode performance events
 License:MIT
 Group:  Development/Libraries/C and C++
 Url:http://perfmon2.sourceforge.net/
 Source: 
http://downloads.sourceforge.net/project/perfmon2/libpfm4/%{name}-%{version}.tar.gz
 Source1:baselibs.conf
-%if %{with_python}
 BuildRequires:  python-devel
 BuildRequires:  swig
-%endif
 BuildRoot:  %{_tmppath}/%{name}-%{version}-build
 
 %description
@@ -64,55 +60,42 @@
 %packagedevel-static
 Summary:Static library version of libpfm
 Group:  Development/Libraries/C and C++
-Requires:   %name-devel = %version
+Requires:   %{name}-devel = %{version}
 
 %description devel-static
 This package contains the static variant of libpfm.
 
-%if %{with_python}
-%package -n python-%name
+%package -n python-%{name}
 Summary:Python bindings for libpfm and perf_event_open system call
 Group:  Development/Libraries/Python
 Requires:   %{vname} = %{version}
 
-%description -n python-%name
+%description -n python-%{name}
 This package provides python bindings for the libpfm4 package and the 
perf_event_open system call.
-%endif
 
 %prep
 %setup -q
 
 %build
-%if %{with_python}
 %global python_config CONFIG_PFMLIB_NOPYTHON=n
-%else
-%global python_config CONFIG_PFMLIB_NOPYTHON=y
-%endif
 make %{?_smp_mflags} %{python_config}
 
 %install
-
-%if %{with_python}
-%global python_config CONFIG_PFMLIB_NOPYTHON=n 
PYTHON_PREFIX="%buildroot/%py_prefix"
-%else
-%global python_config CONFIG_PFMLIB_NOPYTHON=y
-%endif
-
+%global python_config CONFIG_PFMLIB_NOPYTHON=n 
PYTHON_PREFIX="%{buildroot}/%{py_prefix}"
 make \
-PREFIX="%buildroot/%_prefix" \
-LIBDIR="%buildroot/%_libdir" \
+PREFIX="%{buildroot}/%{_prefix}" \
+LIBDIR="%{buildroot}/%{_libdir}" \
 %{python_config} \
 LDCONFIG=/bin/true \
 install
 
-%if %{with_python}
 # temp hack to fix rpmlint file-contains-buildroot for *.pyc
 # http://lists.opensuse.org/opensuse-factory/2012-01/msg00235.html
 find "%{buildroot}/%{python_sitearch}/" -name '*.pyc' -delete
-%__python -c 'import compileall; 
compileall.compile_dir("%{buildroot}%{python_sitearch}/", 
ddir="%{python_sitearch}/", force=1)'
-%endif
+python -c 'import compileall; 
compileall.compile_dir("%{buildroot}%{python_sitearch}/", 
ddir="%{python_sitearch}/", force=1)'
 
 %post -n %{vname} -p /sbin/ldconfig
+
 %postun-n %{vname} -p /sbin/ldconfig
 
 %files -n %{vname}
@@ -130,10 +113,8 @@
 %defattr(-,root,root)
 %{_libdir}/lib*.a
 
-%if %{with_python}
-%files -n python-%name
+%files -n python-%{name}
 %defattr(644,root,root,755)
 %attr(755,root,root) %{python_sitearch}/*
-%endif
 
 %changelog

++ libpfm-4.5.0.tar.gz -> libpfm-4.6.0.tar.gz ++
 16267 lines of diff (skipped)

-- 
To unsubscribe, e-mail: opensuse-commit+unsubscr...@opensuse.org
For a

commit libpfm for openSUSE:Factory

2015-02-16 Thread h_root
Hello community,

here is the log from the commit of package libpfm for openSUSE:Factory checked 
in at 2015-02-16 21:14:49

Comparing /work/SRC/openSUSE:Factory/libpfm (Old)
 and  /work/SRC/openSUSE:Factory/.libpfm.new (New)


Package is "libpfm"

Changes:

--- /work/SRC/openSUSE:Factory/libpfm/libpfm.changes2013-12-05 
07:17:38.0 +0100
+++ /work/SRC/openSUSE:Factory/.libpfm.new/libpfm.changes   2015-02-16 
21:14:50.0 +0100
@@ -1,0 +2,16 @@
+Mon Feb 16 10:04:31 UTC 2015 - p.drou...@gmail.com
+
+- Update to version 4.5.0
+  * Intel IVB-EP uncore PMU support
+  * Intel Silvermont support
+  * Perf raw event syntax support
+  * Intel RAPL event support
+  * AMD Fam15h northbridge support
+  * Qualcomm Krait support
+  * IBM Power 8 support
+  * IBM s390 updates
+  * AMD Fam15h fixes
+  * various IVB, SNB, HSW event table updates
+  * more bug fixes
+
+---

Old:

  libpfm-4.4.0.tar.gz

New:

  libpfm-4.5.0.tar.gz



Other differences:
--
++ libpfm.spec ++
--- /var/tmp/diff_new_pack.Ks08Kj/_old  2015-02-16 21:14:51.0 +0100
+++ /var/tmp/diff_new_pack.Ks08Kj/_new  2015-02-16 21:14:51.0 +0100
@@ -1,7 +1,7 @@
 #
 # spec file for package libpfm
 #
-# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
+# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
 #
 # All modifications and additions to the file contributed by third parties
 # remain the property of their copyright owners, unless otherwise agreed
@@ -19,7 +19,7 @@
 %{!?with_python: %global with_python 1}
 
 Name:   libpfm
-Version:4.4.0
+Version:4.5.0
 Release:0
 %define vname   libpfm4
 Summary:Library to encode performance events

++ libpfm-4.4.0.tar.gz -> libpfm-4.5.0.tar.gz ++
 16738 lines of diff (skipped)

-- 
To unsubscribe, e-mail: opensuse-commit+unsubscr...@opensuse.org
For additional commands, e-mail: opensuse-commit+h...@opensuse.org



commit libpfm for openSUSE:Factory

2013-12-04 Thread h_root
Hello community,

here is the log from the commit of package libpfm for openSUSE:Factory checked 
in at 2013-12-05 07:17:36

Comparing /work/SRC/openSUSE:Factory/libpfm (Old)
 and  /work/SRC/openSUSE:Factory/.libpfm.new (New)


Package is "libpfm"

Changes:

--- /work/SRC/openSUSE:Factory/libpfm/libpfm.changes2013-01-29 
14:16:10.0 +0100
+++ /work/SRC/openSUSE:Factory/.libpfm.new/libpfm.changes   2013-12-05 
07:17:38.0 +0100
@@ -1,0 +2,15 @@
+Wed Dec  4 19:25:33 UTC 2013 - to...@suse.com
+
+- Update to version 4.4.
+- Changelog:
+  - Intel SandyBridge-EP uncore PMU support (all boxes)
+  - Intel IvyBridge desktop core and uncore PMU support
+  - Intel IvyBridge-EP core PMU support
+  - newer Intel Haswell desktop core PMU support
+  - newer Intel Atom
+  - Intel Knigts Corner
+  - Intel Nehalem, Westmere, SandyBridge, IvyBridge, Haswell PEBS Load Latency 
+modifier (ldlat)
+  - many bug fixes and other minor improvements 
+
+---

Old:

  libpfm-4.3.0.tar.bz2

New:

  libpfm-4.4.0.tar.gz



Other differences:
--
++ libpfm.spec ++
--- /var/tmp/diff_new_pack.EEDmfa/_old  2013-12-05 07:17:38.0 +0100
+++ /var/tmp/diff_new_pack.EEDmfa/_new  2013-12-05 07:17:38.0 +0100
@@ -19,14 +19,14 @@
 %{!?with_python: %global with_python 1}
 
 Name:   libpfm
-Version:4.3.0
+Version:4.4.0
 Release:0
 %define vname   libpfm4
 Summary:Library to encode performance events
 License:MIT
 Group:  Development/Libraries/C and C++
 Url:http://perfmon2.sourceforge.net/
-Source: %{name}-%{version}.tar.bz2
+Source: 
http://downloads.sourceforge.net/project/perfmon2/libpfm4/%{name}-%{version}.tar.gz
 Source1:baselibs.conf
 %if %{with_python}
 BuildRequires:  python-devel

-- 
To unsubscribe, e-mail: opensuse-commit+unsubscr...@opensuse.org
For additional commands, e-mail: opensuse-commit+h...@opensuse.org



commit libpfm for openSUSE:Factory

2013-01-29 Thread h_root
Hello community,

here is the log from the commit of package libpfm for openSUSE:Factory checked 
in at 2013-01-29 14:16:09

Comparing /work/SRC/openSUSE:Factory/libpfm (Old)
 and  /work/SRC/openSUSE:Factory/.libpfm.new (New)


Package is "libpfm", Maintainer is "to...@suse.com"

Changes:

--- /work/SRC/openSUSE:Factory/libpfm/libpfm.changes2013-01-10 
13:10:39.0 +0100
+++ /work/SRC/openSUSE:Factory/.libpfm.new/libpfm.changes   2013-01-29 
14:16:10.0 +0100
@@ -1,0 +2,6 @@
+Mon Jan 28 14:02:53 UTC 2013 - dims...@opensuse.org
+
+- Add baselibs.conf: provide libpfm4 as -32bit (makes papi-32bit
+  installable).
+
+---

New:

  baselibs.conf



Other differences:
--
++ libpfm.spec ++
--- /var/tmp/diff_new_pack.o5fwaV/_old  2013-01-29 14:16:11.0 +0100
+++ /var/tmp/diff_new_pack.o5fwaV/_new  2013-01-29 14:16:11.0 +0100
@@ -27,6 +27,7 @@
 Group:  Development/Libraries/C and C++
 Url:http://perfmon2.sourceforge.net/
 Source: %{name}-%{version}.tar.bz2
+Source1:baselibs.conf
 %if %{with_python}
 BuildRequires:  python-devel
 BuildRequires:  swig

++ baselibs.conf ++
libpfm4
-- 
To unsubscribe, e-mail: opensuse-commit+unsubscr...@opensuse.org
For additional commands, e-mail: opensuse-commit+h...@opensuse.org



commit libpfm for openSUSE:Factory

2013-01-10 Thread h_root
Hello community,

here is the log from the commit of package libpfm for openSUSE:Factory checked 
in at 2013-01-10 13:10:37

Comparing /work/SRC/openSUSE:Factory/libpfm (Old)
 and  /work/SRC/openSUSE:Factory/.libpfm.new (New)


Package is "libpfm", Maintainer is "to...@suse.com"

Changes:

New Changes file:

--- /dev/null   2013-01-09 19:40:42.352580873 +0100
+++ /work/SRC/openSUSE:Factory/.libpfm.new/libpfm.changes   2013-01-10 
13:10:39.0 +0100
@@ -0,0 +1,25 @@
+---
+Wed Jan  9 14:18:06 CET 2013 - p...@suse.de
+
+- Run service to format spec file.
+- Small cosmetic changes in spec file.
+
+---
+Tue Jan  8 00:13:39 UTC 2013 - to...@suse.com
+
+- Changes to python builds, drop duplicate defns already in system macros.
+- Fix build when with_python=0
+
+---
+Fri Jan  4 08:19:57 UTC 2013 - jeng...@inai.de
+
+- Parallel build, remove redundant %clean section, consistent use
+  of %buildroot
+- Follow python package naming guidelines
+- Separate out static library into distinct subpackage
+
+---
+Sat Dec 29 20:52:00 UTC 2012 - to...@suse.com
+
+- Initial checkin of libpfm4 (version 4.3). 
+

New:

  libpfm-4.3.0.tar.bz2
  libpfm.changes
  libpfm.spec



Other differences:
diff --git a/include/perfmon/pfmlib.h b/include/perfmon/pfmlib.h
index 20d5feb..3f1d2f5 100644
--- a/include/perfmon/pfmlib.h
+++ b/include/perfmon/pfmlib.h
@@ -543,12 +543,14 @@ typedef enum {

PFM_PMU_INTEL_KNM_UNC_UBOX, /* Intel Knights Mill Ubox uncore */
PFM_PMU_INTEL_KNM_UNC_M2PCIE,   /* Intel Knights Mill M2PCIe uncore */
-   PFM_PMU_ARM_THUNDERX2,  /* Cavium ThunderX2 */
+   PFM_PMU_ARM_THUNDERX2,  /* Marvell ThunderX2 */
 
-   PFM_PMU_ARM_THUNDERX2_DMC0, /* Cavium ThunderX2 DMC unit 0 uncore */
-   PFM_PMU_ARM_THUNDERX2_DMC1, /* Cavium ThunderX2 DMC unit 1 uncore */
-   PFM_PMU_ARM_THUNDERX2_LLC0, /* Cavium ThunderX2 LLC unit 0 uncore */
-   PFM_PMU_ARM_THUNDERX2_LLC1, /* Cavium ThunderX2 LLC unit 1 uncore */
+   PFM_PMU_ARM_THUNDERX2_DMC0, /* Marvell ThunderX2 DMC unit 0 uncore 
*/
+   PFM_PMU_ARM_THUNDERX2_DMC1, /* Marvell ThunderX2 DMC unit 1 uncore 
*/
+   PFM_PMU_ARM_THUNDERX2_LLC0, /* Marvell ThunderX2 LLC unit 0 uncore 
*/
+   PFM_PMU_ARM_THUNDERX2_LLC1, /* Marvell ThunderX2 LLC unit 1 uncore 
*/
+   PFM_PMU_ARM_THUNDERX2_CCPI0,/* Marvell ThunderX2 Cross-Socket 
Interconnect unit 0 uncore */
+   PFM_PMU_ARM_THUNDERX2_CCPI1,/* Marvell ThunderX2 Cross-Socket 
Interconnect unit 1 uncore */
/* MUST ADD NEW PMU MODELS HERE */
 
PFM_PMU_MAX /* end marker */
--
++ libpfm.spec ++
#
# spec file for package libpfm
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{!?with_python: %global with_python 1}

Name:   libpfm
Version:4.3.0
Release:0
%define vname   libpfm4
Summary:Library to encode performance events
License:MIT
Group:  Development/Libraries/C and C++
Url:http://perfmon2.sourceforge.net/
Source: %{name}-%{version}.tar.bz2
%if %{with_python}
BuildRequires:  python-devel
BuildRequires:  swig
%endif
BuildRoot:  %{_tmppath}/%{name}-%{version}-build

%description
This package provides a library that can be used to encode events into the
format required by the operating systems performance monitoring subsystem.

%package -n %{vname}
Summary:Runtime library to encode performance events for use by perf 
tool
Group:  System/Libraries

%description -n %{vname}
This package provides a library that can be used to encode events into the 
format required by the operating systems performance monitoring subsystem.
The library does not make any performance monitoring system calls, it simply 
provides a method to convert an event name, expressed as a string, to an event 
encoding. The user of the library may use this event encoding in a subsequent 
system call.

The current libpfm4 provides support for the perf_events interface which was
introduced in Linux v2.6.31.

%packagedevel
Summary:Development library to encode performance events for 
perf_events interface
Group:  Development/Libraries/C and C++
Requires:   %{vname} = %{version}

%description devel
This package provides development libraries and header files used to encode 
performance events for perf_events interface.

%packagedevel-static
Summary:Static library version of libpfm
Group:  Development/Libraries/C and C++
Requires:   %name-devel = %version

%description devel-static
This package contains the static variant of libpfm.

%if %{with_python}
%package -n python-%name
Summary:Python bindings for libpfm and perf_event_open system call
Group:  Development/Libraries/Python
Requires:   %{vname} = %{version}

%description -n python-%name
This package provides python bindings for the libpfm4 package and the 
perf_event_open system call.
%endif

%prep
%setup -q

%build
%if %{with_python}
%global python_config CONFIG_PFMLIB_NOPYTHON=n
%else
%global python_config CONFIG_PFMLIB_NOPYTHON=y
%endif
make %{?_smp_mflags} %{python_config}

%install

%if %{with_python}
%global python_config CONFIG_PFMLIB_NOPYTHON=n 
PYTHON_PREFIX="%buildroot/%py_pr